#OUTPUTS
SHEXC = "ShEx"
SHACL_TURTLE = "Shacl"

#INPUT FORMATS
NT = "nt"
TSV_SPO = "tsv_spo"
TURTLE = "turtle"
TURTLE_ITER = "turtle_iter"
RDF_XML = "xml"
N3 = "n3"
JSON_LD = "json-ld"

#SHAPE MAP FORMATS
JSON = "json"
FIXED_SHAPE_MAP = "fsm"

#FREQUENT INSTATIATION PROPERTIES
RDF_TYPE = "http://www.w3.org/1999/02/22-rdf-syntax-ns#type"
WIKIDATA_INSTACE_OF = "http://www.wikidata.org/prop/direct/P31"

#NAMESPACES
SHAPES_DEFAULT_NAMESPACE = "http://weso.es/shapes/"

#COMPRESSION FORMATS
ZIP = "zip"
GZ = "gz"

# FREQUENCY MODES

RATIO_INSTANCES = "ratio"
ABSOLUTE_INSTANCES = "abs"
MIXED_INSTANCES = "mixed"
